# -*- coding: utf-8 -*-

"""Top-level package for Styler Identity."""

__author__ = """Bruno Toshio Sugano"""
__email__ = 'bruno.sugano@styler.link'
__version__ = '0.5.1'


from styler_identity.identity import Identity
